@@ -5,7 +5,7 @@ test_that("eia_report returns as expected", {
   expect_is(x, "list")
   expect_equal(length(x), 2)
   expect_equal(names(x), c("data", "counties"))
-  v <- c("Region", "Month", "Rig count", "Production per rig",
+  v <- c("Region", "Fuel", "Month", "Rig count", "Production per rig",
          "Legacy production change", "Total production")
   expect_equal(names(x$data), v)
   v <- c("State", "County", "StateID", "CountyID", "Region")
